@@ -36,6 +36,8 @@ class ConnectionIcon : public QObject
 Q_PROPERTY(bool connecting READ connecting NOTIFY connectingChanged)
 Q_PROPERTY(QString connectionIcon READ connectionIcon NOTIFY connectionIconChanged)
 Q_PROPERTY(QString connectionTooltipIcon READ connectionTooltipIcon NOTIFY connectionTooltipIconChanged)
+
+Q_PROPERTY(bool airplaneMode READ airplaneMode WRITE setAirplaneMode NOTIFY airplaneModeChanged)
 Q_OBJECT
 public:
     explicit ConnectionIcon(QObject* parent = 0);
@@ -45,6 +47,9 @@ public:
     QString connectionIcon() const;
     QString connectionTooltipIcon() const;
 
+    bool airplaneMode() const;
+    void setAirplaneMode(bool airplaneMode);
+
 private Q_SLOTS:
     void activatingConnectionChanged(const QString & connection);
     void activeConnectionAdded(const QString & activeConnection);
@@ -71,6 +76,7 @@ Q_SIGNALS:
     void connectingChanged(bool connecting);
     void connectionIconChanged(const QString & icon);
     void connectionTooltipIconChanged(const QString & icon);
+    void airplaneModeChanged(bool airplaneMode);
 
 private:
     void addActiveConnection(const QString & activeConnection);
@@ -87,6 +93,7 @@ private:
     bool m_vpn;
     QString m_connectionIcon;
     QString m_connectionTooltipIcon;
+    bool m_airplaneMode;
 
     void setDisconnectedIcon();
     void setIcons();
